@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use Clone;
 use HTML::Element;
@@ -20,13 +20,13 @@ sub landscape   { transpose( @_ ) }
 sub transpose   {
     my %args = process( @_ );
     $args{data} = [@{ Math::Matrix::transpose( $args{data} ) }];
-    return _make_table( %args );
+    return _make_table( %args, tgroups => 0 );
 }
 
 sub flip   {
     my %args = process( @_ );
     $args{data} = [ CORE::reverse @{ $args{data} } ];
-    return _make_table( %args );
+    return _make_table( %args, tgroups => 0 );
 }
 
 sub mirror   {
@@ -38,7 +38,7 @@ sub mirror   {
 sub reverse   {
     my %args = process( @_ );
     $args{data} = [ map [ CORE::reverse @$_ ], CORE::reverse @{ $args{data} } ];
-    return _make_table( %args );
+    return _make_table( %args, tgroups => 0 );
 }
 
 sub process {
@@ -51,10 +51,21 @@ sub process {
     my $empty = exists $args->{empty} ? $args->{empty} : '&nbsp;';
     my $max_cols = scalar @{ $data->[0] };
 
+    if ($args->{layout}) {
+        $args->{table}{role}          = 'presentation';
+        $args->{table}{border}        = 0;
+        $args->{table}{cellspacing}   = 0;
+        $args->{table}{cellpadding}   = 0;
+        $args->{encode} = undef; 
+        $args->{matrix} = 1;
+    }
+
     for my $row (0 .. $#$data) {
 
-        push @{ $data->[$row] }, undef for 1 .. $max_cols - $#{ $data->[$row] } + 1;  # pad
-        pop  @{ $data->[$row] } for $max_cols .. $#{ $data->[$row] };                 # truncate
+        unless ($args->{layout}) {
+            push @{ $data->[$row] }, undef for 1 .. $max_cols - $#{ $data->[$row] } + 1;  # pad
+            pop  @{ $data->[$row] } for $max_cols .. $#{ $data->[$row] };                 # truncate
+        }
 
         for my $col (0 .. $#{ $data->[$row] }) {
             my $tag = (!$row and !($args->{headless} or $args->{matrix})) ? 'th' : 'td';
@@ -88,13 +99,32 @@ sub new {
 
 sub _make_table {
     my %args = @_;
-    $args{$_} ||= {} for qw( table tr );
+    $args{$_} ||= {} for qw( table tr thead tbody tfoot );
 
     my $encodes = exists $args{encodes} ? $args{encodes} : '';
 
+    if ($args{tgroups}) {
+        if (scalar @{ $args{data} } > 2) {
+            # replace last row between 1st and 2nd rows
+            splice @{ $args{data} }, 1, 0, pop @{ $args{data} };
+        } else {
+            delete $args{tgroups};
+        }
+    }
+
+    # yes, foot is second and not last
+    my ($head, $foot, @body) = @{ $args{data} };
+
+    my $head_row  = [tr => $args{tr}, @$head];
+    my $foot_row  = [tr => $args{tr}, @{ $foot || [] }];
+    my @body_rows = map [tr => $args{tr}, @$_ ], @body;
+
     my $table = HTML::Element->new_from_lol(
         [table => $args{table},
-            map [tr => $args{tr}, @$_ ], @{ $args{data} }
+            ( $args{caption} ? [caption => {}, $args{caption}] : () ),
+            ( $args{tgroups} ? [ thead => $args{thead}, $head_row ]  : $head_row ),
+            ( $args{tgroups} ? [ tfoot => $args{tfoot}, $foot_row ]  : $foot ? $foot_row : () ),
+              $args{tgroups} ? [ tbody => $args{tbody}, @body_rows ] : @body_rows
         ],
     );
 
@@ -160,35 +190,13 @@ __END__
 
 Spreadsheet::HTML - Render HTML tables with ease.
 
-=head1 THIS IS AN ALPHA RELEASE.
-
-While most functionality for this module has been completed,
-that final 10% takes 90% of the time ... there is still much
-todo:
-
-=over 4
-
-=item * emit col, colgroup, thead, tbody and caption tags ... maybe ...
-
-=item * map client functions to cells
-
-=item * assign attrs to td tags by row
-
-=item * do that nifty rotating attr value trick
-
-=back
-
-You are encouraged to try my older L<DBIx::XHTML_Table> during
-the development of this module, which provides support for 
-tags such as caption, col, colgroup, thead, and tbody.
-
 =head1 SYNOPSIS
 
     use Spreadsheet::HTML;
 
     $data = [ [qw(a1 a2 a3)], [qw(b1 b2 b3)], [qw(c1 c2 c3)] ];
 
-    $table = Spreadsheet::HTML->new( data => $data );
+    $table = Spreadsheet::HTML->new( data => $data, indent => "\t" );
     print $table->portrait;
     print $table->landscape;
 
@@ -196,8 +204,8 @@ tags such as caption, col, colgroup, thead, and tbody.
     print Spreadsheet::HTML::portrait( $data );
     print Spreadsheet::HTML::landscape( $data );
 
-    # load from files
-    $table = Spreadsheet::HTML->new( file => 'data.csv', cache => 1 );
+    # load from files (first table found)
+    $table = Spreadsheet::HTML->new( file => 'data.xls', cache => 1 );
 
 =head1 METHODS
 
@@ -272,8 +280,7 @@ The data to be rendered into table cells.
 =item * C<file: $str>
 
 The name of the data file to read. Supported formats
-are CSV, JSON, YAML and HTML (first table found).
-Support for Excel files is planned.
+are XLS, CSV, JSON, YAML and HTML (first table found).
 
 =item * C<indent: $str>
 
@@ -303,6 +310,12 @@ Preserve data after it has been processed (and loaded).
 
 Render the table with only td tags, no th tags, if true.
 
+=item * C<layout: 0 or 1>
+
+Add W3C recommended table attributes, emit only <td> tags,
+no row padding or pruning, and force no HTML entity encoding
+in table cells.
+
 =item * C<headless: 0 or 1>
 
 Render the table with without headings, if true.
@@ -311,13 +324,22 @@ Render the table with without headings, if true.
 
 Apply this anonymous subroutine to headers.
 
-=item * C<table: { %args }>
+=item * C<tgroups: 0 or 1>
 
-=item * C<tr: { %args }>
+Group table rows into <thead> <tfoot> and <tbody>
+sections. The <tfoot> section is always found before
+the <tbody> section. Only available for C<generate()>,
+C<portrait()> and C<mirror()>.
 
-=item * C<th: { %args }>
+=item * C<table: \%args>
 
-=item * C<td: { %args }>
+=item * C<caption: $str>
+
+=item * C<tr: \%args>
+
+=item * C<th: \%args>
+
+=item * C<td: \%args>
 
 Supply attributes to the HTML tags that compose the table.
 There is currently no support for col, colgroup, caption,
@@ -352,15 +374,17 @@ Used to load data from various different file formats.
 
 =over 4
 
+=item * L<JSON>
+
+=item * L<YAML>
+
 =item * L<Text::CSV>
 
 =item * L<Text::CSV_XS>
 
 =item * L<HTML::TableExtract>
 
-=item * L<JSON>
-
-=item * L<YAML>
+=item * L<Spreadsheet::ParseExcel>
 
 =back
 
@@ -379,6 +403,32 @@ value contol, rotating attributes and totals/subtotals.
 
 =back
 
+=head1 REFERENCE
+
+=over 4
+
+=item * L<http://www.w3.org/TR/html5/tabular-data.html>
+
+=back
+
+=head1 THIS IS AN ALPHA RELEASE.
+
+Left TODO before considerd BETA:
+
+=over 4
+
+=item * emit col and colgroup tags by rows
+
+=item * map client functions to cells by columns
+
+=item * assign attrs to td tags by columns, etc.
+
+=item * do that nifty rotating attr value trick
+
+=back
+
+You are encouraged to L<DBIx::XHTML_Table> during the development of this module.
+
 =head1 BUGS
 
 Please report any bugs or feature requests to either
