@@ -1,13 +1,16 @@
 package Spreadsheet::HTML::JSON;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.00';
+our $VERSION = '0.01';
 
 use Carp;
 eval "use JSON";
+our $NOT_AVAILABLE = $@;
 
 sub load {
     my $file = shift;
+    return [[ "cannot load $file" ],[ 'please install JSON' ]] if $NOT_AVAILABLE;
+
     open my $fh, '<', $file or croak "Cannot read $file: $!\n";
     my $data = decode_json( do{ local $/; <$fh> } );
     close $fh;
